==> openshift-model-operatorhub-5.7.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/UpdateStrategyFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class UpdateStrategyFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent<A>{
  public UpdateStrategyFluentImpl() {
  }
  public UpdateStrategyFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategy instance) {
    this.withRegistryPoll(instance.getRegistryPoll()); 
  }
  private io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPollBuilder registryPoll;
  
  /**
   * This method has been deprecated, please use method buildRegistryPoll instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPoll getRegistryPoll() {
    return this.registryPoll!=null?this.registryPoll.build():null;
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPoll buildRegistryPoll() {
    return this.registryPoll!=null?this.registryPoll.build():null;
  }
  public A withRegistryPoll(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPoll registryPoll) {
    _visitables.get("registryPoll").remove(this.registryPoll);
    if (registryPoll!=null){ this.registryPoll= new io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPollBuilder(registryPoll); _visitables.get("registryPoll").add(this.registryPoll);} return (A) this;
  }
  public java.lang.Boolean hasRegistryPoll() {
    return this.registryPoll != null;
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent.RegistryPollNested<A> withNewRegistryPoll() {
    return new io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluentImpl.RegistryPollNestedImpl();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent.RegistryPollNested<A> withNewRegistryPollLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPoll item) {
    return new io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluentImpl.RegistryPollNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent.RegistryPollNested<A> editRegistryPoll() {
    return withNewRegistryPollLike(getRegistryPoll());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent.RegistryPollNested<A> editOrNewRegistryPoll() {
    return withNewRegistryPollLike(getRegistryPoll() != null ? getRegistryPoll(): new io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPollBuilder().build());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent.RegistryPollNested<A> editOrNewRegistryPollLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPoll item) {
    return withNewRegistryPollLike(getRegistryPoll() != null ? getRegistryPoll(): item);
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    UpdateStrategyFluentImpl that = (UpdateStrategyFluentImpl) o;
    if (registryPoll != null ? !registryPoll.equals(that.registryPoll) :that.registryPoll != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(registryPoll,  super.hashCode());
  }
  public class RegistryPollNestedImpl<N> extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPollFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent.RegistryPollNested<N>> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent.RegistryPollNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    RegistryPollNestedImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPoll item) {
      this.builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPollBuilder(this, item);
    }
    RegistryPollNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPollBuilder(this);
    }
    io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPollBuilder builder;
    public N and() {
      return (N) UpdateStrategyFluentImpl.this.withRegistryPoll(builder.build());
    }
    public N endRegistryPoll() {
      return and();
    }
    
  }
  
}

==> openshift-model-operatorhub-5.11.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/UpdateStrategyFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class UpdateStrategyFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent<A>{
  public UpdateStrategyFluentImpl() {
  }
  public UpdateStrategyFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategy instance) {
    this.withRegistryPoll(instance.getRegistryPoll()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPollBuilder registryPoll;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildRegistryPoll instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPoll getRegistryPoll() {
    return this.registryPoll!=null?this.registryPoll.build():null;
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPoll buildRegistryPoll() {
    return this.registryPoll!=null?this.registryPoll.build():null;
  }
  public A withRegistryPoll(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPoll registryPoll) {
    _visitables.get("registryPoll").remove(this.registryPoll);
    if (registryPoll!=null){ this.registryPoll= new io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPollBuilder(registryPoll); _visitables.get("registryPoll").add(this.registryPoll);} return (A) this;
  }
  public java.lang.Boolean hasRegistryPoll() {
    return this.registryPoll != null;
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent.RegistryPollNested<A> withNewRegistryPoll() {
    return new io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluentImpl.RegistryPollNestedImpl();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent.RegistryPollNested<A> withNewRegistryPollLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPoll item) {
    return new io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluentImpl.RegistryPollNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent.RegistryPollNested<A> editRegistryPoll() {
    return withNewRegistryPollLike(getRegistryPoll());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent.RegistryPollNested<A> editOrNewRegistryPoll() {
    return withNewRegistryPollLike(getRegistryPoll() != null ? getRegistryPoll(): new io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPollBuilder().build());
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent.RegistryPollNested<A> editOrNewRegistryPollLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPoll item) {
    return withNewRegistryPollLike(getRegistryPoll() != null ? getRegistryPoll(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    UpdateStrategyFluentImpl that = (UpdateStrategyFluentImpl) o;
    if (registryPoll != null ? !registryPoll.equals(that.registryPoll) :that.registryPoll != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(registryPoll,  additionalProperties,  super.hashCode());
  }
  public class RegistryPollNestedImpl<N> extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPollFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent.RegistryPollNested<N>> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.UpdateStrategyFluent.RegistryPollNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    RegistryPollNestedImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPoll item) {
      this.builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPollBuilder(this, item);
    }
    RegistryPollNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPollBuilder(this);
    }
    io.fabric8.openshift.api.model.operatorhub.v1alpha1.RegistryPollBuilder builder;
    public N and() {
      return (N) UpdateStrategyFluentImpl.this.withRegistryPoll(builder.build());
    }
    public N endRegistryPoll() {
      return and();
    }
    
  }
  
}
